@@ -22,13 +22,11 @@
 """
 
 import os
-import time
-import datetime
 import unittest
 import logging
 import tempfile
 import shutil
-import unittest
+import sys
 
 import tuf
 import tuf.log
@@ -43,6 +41,8 @@ import securesystemslib.exceptions
 from tuf.developer_tool import METADATA_DIRECTORY_NAME
 from tuf.developer_tool import TARGETS_DIRECTORY_NAME
 
+from tests import utils
+
 logger = logging.getLogger(__name__)
 
 developer_tool.disable_console_log_messages()
@@ -55,13 +55,11 @@ class TestProject(unittest.TestCase):
   def setUpClass(cls):
     cls.tmp_dir = tempfile.mkdtemp(dir = os.getcwd())
 
+
   @classmethod
   def tearDownClass(cls):
     shutil.rmtree(cls.tmp_dir)
 
-  def setUp(self):
-    # called before every test case
-    pass
 
   def tearDown(self):
     # called after every test case
@@ -426,4 +424,5 @@ class TestProject(unittest.TestCase):
 
 
 if __name__ == '__main__':
+  utils.configure_test_logging(sys.argv)
   unittest.main()
