@@ -20,14 +20,6 @@
   Unit test for 'formats.py'
 """
 
-# Help with Python 3 compatibility, where the print statement is a function, an
-# implicit relative import is invalid, and the '/' operator performs true
-# division.  Example:  print 'hello world' raises a 'SyntaxError' exception.
-from __future__ import print_function
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
-
 import unittest
 import datetime
 import sys
@@ -40,7 +32,6 @@ from tests import utils
 
 import securesystemslib
 import securesystemslib.util
-import six
 
 
 class TestFormats(unittest.TestCase):
@@ -287,7 +278,7 @@ class TestFormats(unittest.TestCase):
 
     # Iterate 'valid_schemas', ensuring each 'valid_schema' correctly matches
     # its respective 'schema_type'.
-    for schema_name, (schema_type, valid_schema) in six.iteritems(valid_schemas):
+    for schema_name, (schema_type, valid_schema) in valid_schemas.items():
       if not schema_type.matches(valid_schema):
         print('bad schema: ' + repr(valid_schema))
       self.assertEqual(True, schema_type.matches(valid_schema))
@@ -295,7 +286,7 @@ class TestFormats(unittest.TestCase):
     # Test conditions for invalid schemas.
     # Set the 'valid_schema' of 'valid_schemas' to an invalid
     # value and test that it does not match 'schema_type'.
-    for schema_name, (schema_type, valid_schema) in six.iteritems(valid_schemas):
+    for schema_name, (schema_type, valid_schema) in valid_schemas.items():
       invalid_schema = 0xBAD
       if isinstance(schema_type, securesystemslib.schema.Integer):
         invalid_schema = 'BAD'
@@ -779,7 +770,7 @@ class TestFormats(unittest.TestCase):
     # Test conditions for valid arguments.
     data = 'updateframework'.encode('utf-8')
     self.assertEqual('dXBkYXRlZnJhbWV3b3Jr', tuf.formats.format_base64(data))
-    self.assertTrue(isinstance(tuf.formats.format_base64(data), six.string_types))
+    self.assertTrue(isinstance(tuf.formats.format_base64(data), str))
 
     # Test conditions for invalid arguments.
     self.assertRaises(securesystemslib.exceptions.FormatError, tuf.formats.format_base64, 123)
@@ -791,7 +782,7 @@ class TestFormats(unittest.TestCase):
     # Test conditions for valid arguments.
     base64 = 'dXBkYXRlZnJhbWV3b3Jr'
     self.assertEqual(b'updateframework', tuf.formats.parse_base64(base64))
-    self.assertTrue(isinstance(tuf.formats.parse_base64(base64), six.binary_type))
+    self.assertTrue(isinstance(tuf.formats.parse_base64(base64), bytes))
 
     # Test conditions for invalid arguments.
     self.assertRaises(securesystemslib.exceptions.FormatError, tuf.formats.parse_base64, 123)
