@@ -29,14 +29,6 @@
   'tests/unittest_toolbox.py'.
 """
 
-# Help with Python 3 compatibility, where the print statement is a function, an
-# implicit relative import is invalid, and the '/' operator performs true
-# division.  Example:  print 'hello world' raises a 'SyntaxError' exception.
-from __future__ import print_function
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
-
 import os
 import shutil
 import tempfile
@@ -55,7 +47,6 @@ import tuf.client.updater as updater
 from tests import utils
 
 import securesystemslib
-import six
 
 logger = logging.getLogger(__name__)
 repo_tool.disable_console_log_messages()
@@ -132,7 +123,7 @@ class TestKeyRevocation(unittest_toolbox.Modified_TestCase):
 
     # 'path/to/tmp/repository' -> 'localhost:8001/tmp/repository'.
     repository_basepath = self.repository_directory[len(os.getcwd()):]
-    url_prefix = 'http://localhost:' \
+    url_prefix = 'http://' + utils.TEST_HOST_ADDRESS + ':' \
       + str(self.server_process_handler.port) + repository_basepath
 
     # Setting 'tuf.settings.repository_directory' with the temporary client
@@ -156,14 +147,15 @@ class TestKeyRevocation(unittest_toolbox.Modified_TestCase):
 
 
   def tearDown(self):
-    # We are inheriting from custom class.
-    unittest_toolbox.Modified_TestCase.tearDown(self)
     tuf.roledb.clear_roledb(clear_all=True)
     tuf.keydb.clear_keydb(clear_all=True)
 
     # Logs stdout and stderr from the sever subprocess.
     self.server_process_handler.flush_log()
 
+    # Remove temporary directory
+    unittest_toolbox.Modified_TestCase.tearDown(self)
+
 
   # UNIT TESTS.
   def test_timestamp_key_revocation(self):
