@@ -20,14 +20,6 @@
   Unit test for 'roledb.py'.
 """
 
-# Help with Python 3 compatibility, where the print statement is a function, an
-# implicit relative import is invalid, and the '/' operator performs true
-# division.  Example:  print 'hello world' raises a 'SyntaxError' exception.
-from __future__ import print_function
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
-
 import unittest
 import logging
 import sys
@@ -96,7 +88,7 @@ class TestRoledb(unittest.TestCase):
 
     tuf.roledb.remove_roledb(repository_name)
 
-    # remove_roledb() should not raise an excepion if a non-existent
+    # remove_roledb() should not raise an exception if a non-existent
     # 'repository_name' is specified.
     tuf.roledb.remove_roledb(repository_name)
 
