@@ -21,13 +21,6 @@
 
 """
 
-# Help with Python 3 compatibility, where the print statement is a function, an
-# implicit relative import is invalid, and the '/' operator performs true
-# division.  Example:  print 'hello world' raises a 'SyntaxError' exception.
-from __future__ import print_function
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
 
 import unittest
 import datetime # part of TUTORIAL.md
@@ -396,9 +389,6 @@ class TestTutorial(unittest.TestCase):
 
     # TODO: Run subprocess to simulate the following bash instructions:
 
-    # $ cd "repository/"; python -m SimpleHTTPServer 8001
-    # If running Python 3:
-
     # $ cd "repository/"; python3 -m http.server 8001
     # We next retrieve targets from the TUF repository and save them to client/. The client.py script is available to download metadata and files from a specified repository. In a different command-line prompt . . .
 
