@@ -33,14 +33,6 @@
   less dependent than 2.
 """
 
-# Help with Python 3 compatibility, where the print statement is a function, an
-# implicit relative import is invalid, and the '/' operator performs true
-# division.  Example:  print 'hello world' raises a 'SyntaxError' exception.
-from __future__ import print_function
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
-
 import os
 import shutil
 import tempfile
@@ -62,7 +54,6 @@ import tuf.settings
 from tests import utils
 
 import securesystemslib
-import six
 
 logger = logging.getLogger(__name__)
 repo_tool.disable_console_log_messages()
@@ -140,7 +131,7 @@ class TestUpdater(unittest_toolbox.Modified_TestCase):
 
     # 'path/to/tmp/repository' -> 'localhost:8001/tmp/repository'.
     repository_basepath = self.repository_directory[len(os.getcwd()):]
-    url_prefix = 'http://localhost:' \
+    url_prefix = 'http://' + utils.TEST_HOST_ADDRESS + ':' \
         + str(self.server_process_handler.port) + repository_basepath
 
     # Setting 'tuf.settings.repository_directory' with the temporary client
@@ -164,14 +155,15 @@ class TestUpdater(unittest_toolbox.Modified_TestCase):
 
 
   def tearDown(self):
-    # We are inheriting from custom class.
-    unittest_toolbox.Modified_TestCase.tearDown(self)
     tuf.roledb.clear_roledb(clear_all=True)
     tuf.keydb.clear_keydb(clear_all=True)
 
     # Logs stdout and stderr from the sever subprocess.
     self.server_process_handler.flush_log()
 
+    # Remove temporary directory
+    unittest_toolbox.Modified_TestCase.tearDown(self)
+
 
   # UNIT TESTS.
   def test_root_rotation(self):
@@ -248,7 +240,7 @@ class TestUpdater(unittest_toolbox.Modified_TestCase):
      with self.assertRaises(tuf.exceptions.NoWorkingMirrorError) as cm:
        self.repository_updater.refresh()
 
-     for mirror_url, mirror_error in six.iteritems(cm.exception.mirror_errors):
+     for mirror_url, mirror_error in cm.exception.mirror_errors.items():
        self.assertTrue(mirror_url.endswith('/2.root.json'))
        self.assertTrue(isinstance(mirror_error,
            securesystemslib.exceptions.BadSignatureError))
@@ -307,7 +299,7 @@ class TestUpdater(unittest_toolbox.Modified_TestCase):
      with self.assertRaises(tuf.exceptions.NoWorkingMirrorError) as cm:
        self.repository_updater.refresh()
 
-     for mirror_url, mirror_error in six.iteritems(cm.exception.mirror_errors):
+     for mirror_url, mirror_error in cm.exception.mirror_errors.items():
        self.assertTrue(mirror_url.endswith('/2.root.json'))
        self.assertTrue(isinstance(mirror_error,
            securesystemslib.exceptions.BadSignatureError))
@@ -450,7 +442,7 @@ class TestUpdater(unittest_toolbox.Modified_TestCase):
     with self.assertRaises(tuf.exceptions.NoWorkingMirrorError) as cm:
       self.repository_updater.refresh()
 
-    for mirror_url, mirror_error in six.iteritems(cm.exception.mirror_errors):
+    for mirror_url, mirror_error in cm.exception.mirror_errors.items():
       self.assertTrue(mirror_url.endswith('/2.root.json'))
       self.assertTrue(isinstance(mirror_error,
           securesystemslib.exceptions.BadSignatureError))
@@ -525,7 +517,7 @@ class TestUpdater(unittest_toolbox.Modified_TestCase):
     with self.assertRaises(tuf.exceptions.NoWorkingMirrorError) as cm:
       self.repository_updater.refresh()
 
-    for mirror_url, mirror_error in six.iteritems(cm.exception.mirror_errors):
+    for mirror_url, mirror_error in cm.exception.mirror_errors.items():
       self.assertTrue(mirror_url.endswith('/3.root.json'))
       self.assertTrue(isinstance(mirror_error,
           securesystemslib.exceptions.BadSignatureError))
@@ -571,7 +563,7 @@ class TestUpdater(unittest_toolbox.Modified_TestCase):
     with self.assertRaises(tuf.exceptions.NoWorkingMirrorError) as cm:
       self.repository_updater.refresh()
 
-    for mirror_url, mirror_error in six.iteritems(cm.exception.mirror_errors):
+    for mirror_url, mirror_error in cm.exception.mirror_errors.items():
       self.assertTrue(mirror_url.endswith('/3.root.json'))
       self.assertTrue(isinstance(mirror_error,
           securesystemslib.exceptions.BadSignatureError))
@@ -606,7 +598,7 @@ class TestUpdater(unittest_toolbox.Modified_TestCase):
     with self.assertRaises(tuf.exceptions.NoWorkingMirrorError) as cm:
       self.repository_updater.refresh()
 
-    for mirror_url, mirror_error in six.iteritems(cm.exception.mirror_errors):
+    for mirror_url, mirror_error in cm.exception.mirror_errors.items():
       self.assertTrue(mirror_url.endswith('/2.root.json'))
       self.assertTrue(isinstance(mirror_error,
           securesystemslib.exceptions.BadSignatureError))
@@ -651,7 +643,7 @@ def _load_role_keys(keystore_directory):
   role_keys['root2']['public'] = \
     repo_tool.import_ed25519_publickey_from_file(root2_key_file+'.pub')
   role_keys['root3']['public'] = \
-    repo_tool.import_ed25519_publickey_from_file(root3_key_file+'.pub')
+    repo_tool.import_ecdsa_publickey_from_file(root3_key_file+'.pub')
   role_keys['targets']['public'] = \
     repo_tool.import_ed25519_publickey_from_file(targets_key_file+'.pub')
   role_keys['snapshot']['public'] = \
@@ -669,7 +661,7 @@ def _load_role_keys(keystore_directory):
     repo_tool.import_ed25519_privatekey_from_file(root2_key_file,
                                               EXPECTED_KEYFILE_PASSWORD)
   role_keys['root3']['private'] = \
-    repo_tool.import_ed25519_privatekey_from_file(root3_key_file,
+    repo_tool.import_ecdsa_privatekey_from_file(root3_key_file,
                                               EXPECTED_KEYFILE_PASSWORD)
   role_keys['targets']['private'] = \
     repo_tool.import_ed25519_privatekey_from_file(targets_key_file,
