@@ -41,23 +41,15 @@
   optional.
 """
 
-# Help with Python 3 compatibility, where the print statement is a function, an
-# implicit relative import is invalid, and the '/' operator performs true
-# division.  Example:  print 'hello world' raises a 'SyntaxError' exception.
-from __future__ import print_function
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
-
 import logging
 import copy
 
-import tuf
-import tuf.log
-import tuf.formats
+import securesystemslib # pylint: disable=unused-import
+from securesystemslib import exceptions as sslib_exceptions
+from securesystemslib import formats as sslib_formats
 
-import securesystemslib
-import six
+from tuf import exceptions
+from tuf import formats
 
 # See 'tuf.log' to learn how logging is handled in TUF.
 logger = logging.getLogger(__name__)
@@ -111,10 +103,10 @@ def create_roledb_from_root_metadata(root_metadata, repository_name='default'):
   # This check will ensure 'root_metadata' has the appropriate number of objects
   # and object types, and that all dict keys are properly named.
   # Raises securesystemslib.exceptions.FormatError.
-  tuf.formats.ROOT_SCHEMA.check_match(root_metadata)
+  formats.ROOT_SCHEMA.check_match(root_metadata)
 
   # Is 'repository_name' formatted correctly?
-  securesystemslib.formats.NAME_SCHEMA.check_match(repository_name)
+  sslib_formats.NAME_SCHEMA.check_match(repository_name)
 
   global _roledb_dict
   global _dirty_roles
@@ -133,7 +125,7 @@ def create_roledb_from_root_metadata(root_metadata, repository_name='default'):
 
   # Iterate the roles found in 'root_metadata' and add them to '_roledb_dict'.
   # Duplicates are avoided.
-  for rolename, roleinfo in six.iteritems(root_metadata['roles']):
+  for rolename, roleinfo in root_metadata['roles'].items():
     if rolename == 'root':
       roleinfo['version'] = root_metadata['version']
       roleinfo['expires'] = root_metadata['expires']
@@ -182,13 +174,13 @@ def create_roledb(repository_name):
 
   # Is 'repository_name' properly formatted?  If not, raise
   # 'securesystemslib.exceptions.FormatError'.
-  securesystemslib.formats.NAME_SCHEMA.check_match(repository_name)
+  sslib_formats.NAME_SCHEMA.check_match(repository_name)
 
   global _roledb_dict
   global _dirty_roles
 
   if repository_name in _roledb_dict or repository_name in _dirty_roles:
-    raise securesystemslib.exceptions.InvalidNameError('Repository name'
+    raise sslib_exceptions.InvalidNameError('Repository name'
       ' already exists: ' + repr(repository_name))
 
   _roledb_dict[repository_name] = {}
@@ -225,7 +217,7 @@ def remove_roledb(repository_name):
 
   # Is 'repository_name' properly formatted?  If not, raise
   # 'securesystemslib.exceptions.FormatError'.
-  securesystemslib.formats.NAME_SCHEMA.check_match(repository_name)
+  sslib_formats.NAME_SCHEMA.check_match(repository_name)
 
   global _roledb_dict
   global _dirty_roles
@@ -236,7 +228,7 @@ def remove_roledb(repository_name):
     return
 
   if repository_name == 'default':
-    raise securesystemslib.exceptions.InvalidNameError('Cannot remove the'
+    raise sslib_exceptions.InvalidNameError('Cannot remove the'
       ' default repository: ' + repr(repository_name))
 
   del _roledb_dict[repository_name]
@@ -294,13 +286,13 @@ def add_role(rolename, roleinfo, repository_name='default'):
   # Does 'rolename' have the correct object format?
   # This check will ensure 'rolename' has the appropriate number of objects
   # and object types, and that all dict keys are properly named.
-  tuf.formats.ROLENAME_SCHEMA.check_match(rolename)
+  formats.ROLENAME_SCHEMA.check_match(rolename)
 
   # Does 'roleinfo' have the correct object format?
-  tuf.formats.ROLEDB_SCHEMA.check_match(roleinfo)
+  formats.ROLEDB_SCHEMA.check_match(roleinfo)
 
   # Is 'repository_name' correctly formatted?
-  securesystemslib.formats.NAME_SCHEMA.check_match(repository_name)
+  sslib_formats.NAME_SCHEMA.check_match(repository_name)
 
   global _roledb_dict
 
@@ -308,10 +300,10 @@ def add_role(rolename, roleinfo, repository_name='default'):
   _validate_rolename(rolename)
 
   if repository_name not in _roledb_dict:
-    raise securesystemslib.exceptions.InvalidNameError('Repository name does not exist: ' + repository_name)
+    raise sslib_exceptions.InvalidNameError('Repository name does not exist: ' + repository_name)
 
   if rolename in _roledb_dict[repository_name]:
-    raise tuf.exceptions.RoleAlreadyExistsError('Role already exists: ' + rolename)
+    raise exceptions.RoleAlreadyExistsError('Role already exists: ' + rolename)
 
   _roledb_dict[repository_name][rolename] = copy.deepcopy(roleinfo)
 
@@ -378,12 +370,12 @@ def update_roleinfo(rolename, roleinfo, mark_role_as_dirty=True, repository_name
   # Does the arguments have the correct object format?
   # This check will ensure arguments have the appropriate number of objects
   # and object types, and that all dict keys are properly named.
-  tuf.formats.ROLENAME_SCHEMA.check_match(rolename)
-  securesystemslib.formats.BOOLEAN_SCHEMA.check_match(mark_role_as_dirty)
-  securesystemslib.formats.NAME_SCHEMA.check_match(repository_name)
+  formats.ROLENAME_SCHEMA.check_match(rolename)
+  sslib_formats.BOOLEAN_SCHEMA.check_match(mark_role_as_dirty)
+  sslib_formats.NAME_SCHEMA.check_match(repository_name)
 
   # Does 'roleinfo' have the correct object format?
-  tuf.formats.ROLEDB_SCHEMA.check_match(roleinfo)
+  formats.ROLEDB_SCHEMA.check_match(roleinfo)
 
   # Raises securesystemslib.exceptions.InvalidNameError.
   _validate_rolename(rolename)
@@ -392,11 +384,11 @@ def update_roleinfo(rolename, roleinfo, mark_role_as_dirty=True, repository_name
   global _dirty_roles
 
   if repository_name not in _roledb_dict or repository_name not in _dirty_roles:
-    raise securesystemslib.exceptions.InvalidNameError('Repository name does not' ' exist: ' +
+    raise sslib_exceptions.InvalidNameError('Repository name does not' ' exist: ' +
       repository_name)
 
   if rolename not in _roledb_dict[repository_name]:
-    raise tuf.exceptions.UnknownRoleError('Role does not exist: ' + rolename)
+    raise exceptions.UnknownRoleError('Role does not exist: ' + rolename)
 
   # Update the global _roledb_dict and _dirty_roles structures so that
   # the latest 'roleinfo' is available to other modules, and the repository
@@ -438,13 +430,13 @@ def get_dirty_roles(repository_name='default'):
 
   # Does 'repository_name' have the correct format?  Raise
   # 'securesystemslib.exceptions.FormatError' if not.
-  securesystemslib.formats.NAME_SCHEMA.check_match(repository_name)
+  sslib_formats.NAME_SCHEMA.check_match(repository_name)
 
   global _roledb_dict
   global _dirty_roles
 
   if repository_name not in _roledb_dict or repository_name not in _dirty_roles:
-    raise securesystemslib.exceptions.InvalidNameError('Repository name does'
+    raise sslib_exceptions.InvalidNameError('Repository name does'
       '  not' ' exist: ' + repository_name)
 
   return sorted(list(_dirty_roles[repository_name]))
@@ -480,14 +472,14 @@ def mark_dirty(roles, repository_name='default'):
 
   # Are the arguments properly formatted?  If not, raise
   # securesystemslib.exceptions.FormatError.
-  securesystemslib.formats.NAMES_SCHEMA.check_match(roles)
-  securesystemslib.formats.NAME_SCHEMA.check_match(repository_name)
+  sslib_formats.NAMES_SCHEMA.check_match(roles)
+  sslib_formats.NAME_SCHEMA.check_match(repository_name)
 
   global _roledb_dict
   global _dirty_roles
 
   if repository_name not in _roledb_dict or repository_name not in _dirty_roles:
-    raise securesystemslib.exceptions.InvalidNameError('Repository name does'
+    raise sslib_exceptions.InvalidNameError('Repository name does'
       ' not' ' exist: ' + repository_name)
 
   _dirty_roles[repository_name].update(roles)
@@ -523,14 +515,14 @@ def unmark_dirty(roles, repository_name='default'):
 
   # Are the arguments properly formatted?  If not, raise
   # securesystemslib.exceptions.FormatError.
-  securesystemslib.formats.NAMES_SCHEMA.check_match(roles)
-  securesystemslib.formats.NAME_SCHEMA.check_match(repository_name)
+  sslib_formats.NAMES_SCHEMA.check_match(roles)
+  sslib_formats.NAME_SCHEMA.check_match(repository_name)
 
   global _roledb_dict
   global _dirty_roles
 
   if repository_name not in _roledb_dict or repository_name not in _dirty_roles:
-    raise securesystemslib.exceptions.InvalidNameError('Repository name does'
+    raise sslib_exceptions.InvalidNameError('Repository name does'
       ' not exist: ' + repository_name)
 
   for role in roles:
@@ -577,7 +569,7 @@ def role_exists(rolename, repository_name='default'):
   try:
     _check_rolename(rolename, repository_name)
 
-  except tuf.exceptions.UnknownRoleError:
+  except exceptions.UnknownRoleError:
     return False
 
   return True
@@ -624,7 +616,7 @@ def remove_role(rolename, repository_name='default'):
 
   # Does 'repository_name' have the correct format?  Raise
   # 'securesystemslib.exceptions.FormatError' if it is improperly formatted.
-  securesystemslib.formats.NAME_SCHEMA.check_match(repository_name)
+  sslib_formats.NAME_SCHEMA.check_match(repository_name)
 
   # Raises securesystemslib.exceptions.FormatError,
   # tuf.exceptions.UnknownRoleError, or
@@ -668,13 +660,13 @@ def get_rolenames(repository_name='default'):
 
   # Does 'repository_name' have the correct format?  Raise
   # 'securesystemslib.exceptions.FormatError' if it is improperly formatted.
-  securesystemslib.formats.NAME_SCHEMA.check_match(repository_name)
+  sslib_formats.NAME_SCHEMA.check_match(repository_name)
 
   global _roledb_dict
   global _dirty_roles
 
   if repository_name not in _roledb_dict or repository_name not in _dirty_roles:
-    raise securesystemslib.exceptions.InvalidNameError('Repository name does'
+    raise sslib_exceptions.InvalidNameError('Repository name does'
       ' not' ' exist: ' + repository_name)
 
   return list(_roledb_dict[repository_name].keys())
@@ -726,7 +718,7 @@ def get_roleinfo(rolename, repository_name='default'):
 
   # Is 'repository_name' properly formatted?  If not, raise
   # 'securesystemslib.exceptions.FormatError'.
-  securesystemslib.formats.NAME_SCHEMA.check_match(repository_name)
+  sslib_formats.NAME_SCHEMA.check_match(repository_name)
 
   # Raises securesystemslib.exceptions.FormatError,
   # tuf.exceptions.UnknownRoleError, or
@@ -779,7 +771,7 @@ def get_role_keyids(rolename, repository_name='default'):
 
   # Raise 'securesystemslib.exceptions.FormatError' if 'repository_name' is
   # improperly formatted.
-  securesystemslib.formats.NAME_SCHEMA.check_match(repository_name)
+  sslib_formats.NAME_SCHEMA.check_match(repository_name)
 
   # Raises securesystemslib.exceptions.FormatError,
   # tuf.exceptions.UnknownRoleError, or
@@ -831,7 +823,7 @@ def get_role_threshold(rolename, repository_name='default'):
 
   # Raise 'securesystemslib.exceptions.FormatError' if 'repository_name' is
   # improperly formatted.
-  securesystemslib.formats.NAME_SCHEMA.check_match(repository_name)
+  sslib_formats.NAME_SCHEMA.check_match(repository_name)
 
   # Raises securesystemslib.exceptions.FormatError,
   # tuf.exceptions.UnknownRoleError, or
@@ -882,7 +874,7 @@ def get_role_paths(rolename, repository_name='default'):
 
   # Raise 'securesystemslib.exceptions.FormatError' if 'repository_name' is
   # improperly formatted.
-  securesystemslib.formats.NAME_SCHEMA.check_match(repository_name)
+  sslib_formats.NAME_SCHEMA.check_match(repository_name)
 
   # Raises securesystemslib.exceptions.FormatError,
   # tuf.exceptions.UnknownRoleError, or
@@ -942,7 +934,7 @@ def get_delegated_rolenames(rolename, repository_name='default'):
 
   # Does 'repository_name' have the correct format?  Raise
   # 'securesystemslib.exceptions.FormatError' if it does not.
-  securesystemslib.formats.NAME_SCHEMA.check_match(repository_name)
+  sslib_formats.NAME_SCHEMA.check_match(repository_name)
 
   # Raises securesystemslib.exceptions.FormatError,
   # tuf.exceptions.UnknownRoleError, or
@@ -995,14 +987,14 @@ def clear_roledb(repository_name='default', clear_all=False):
 
   # Do the arguments have the correct format?  If not, raise
   # 'securesystemslib.exceptions.FormatError'
-  securesystemslib.formats.NAME_SCHEMA.check_match(repository_name)
-  securesystemslib.formats.BOOLEAN_SCHEMA.check_match(clear_all)
+  sslib_formats.NAME_SCHEMA.check_match(repository_name)
+  sslib_formats.BOOLEAN_SCHEMA.check_match(clear_all)
 
   global _roledb_dict
   global _dirty_roles
 
   if repository_name not in _roledb_dict or repository_name not in _dirty_roles:
-    raise securesystemslib.exceptions.InvalidNameError('Repository name does not'
+    raise sslib_exceptions.InvalidNameError('Repository name does not'
       ' exist: ' + repository_name)
 
   if clear_all:
@@ -1030,10 +1022,10 @@ def _check_rolename(rolename, repository_name='default'):
   # Does 'rolename' have the correct object format?
   # This check will ensure 'rolename' has the appropriate number of objects
   # and object types, and that all dict keys are properly named.
-  tuf.formats.ROLENAME_SCHEMA.check_match(rolename)
+  formats.ROLENAME_SCHEMA.check_match(rolename)
 
   # Does 'repository_name' have the correct format?
-  securesystemslib.formats.NAME_SCHEMA.check_match(repository_name)
+  sslib_formats.NAME_SCHEMA.check_match(repository_name)
 
   # Raises securesystemslib.exceptions.InvalidNameError.
   _validate_rolename(rolename)
@@ -1042,11 +1034,11 @@ def _check_rolename(rolename, repository_name='default'):
   global _dirty_roles
 
   if repository_name not in _roledb_dict or repository_name not in _dirty_roles:
-    raise securesystemslib.exceptions.InvalidNameError('Repository name does not'
+    raise sslib_exceptions.InvalidNameError('Repository name does not'
       ' exist: ' + repository_name)
 
   if rolename not in _roledb_dict[repository_name]:
-    raise tuf.exceptions.UnknownRoleError('Role name does not exist: ' + rolename)
+    raise exceptions.UnknownRoleError('Role name does not exist: ' + rolename)
 
 
 
@@ -1059,13 +1051,13 @@ def _validate_rolename(rolename):
   'ROLENAME_SCHEMA' prior to calling this function.  """
 
   if rolename == '':
-    raise securesystemslib.exceptions.InvalidNameError('Rolename must *not* be'
+    raise sslib_exceptions.InvalidNameError('Rolename must *not* be'
       ' an empty string.')
 
   if rolename != rolename.strip():
-    raise securesystemslib.exceptions.InvalidNameError('Invalid rolename.'
+    raise sslib_exceptions.InvalidNameError('Invalid rolename.'
       '  Cannot start or end with whitespace: ' + rolename)
 
   if rolename.startswith('/') or rolename.endswith('/'):
-    raise securesystemslib.exceptions.InvalidNameError('Invalid rolename.'
+    raise sslib_exceptions.InvalidNameError('Invalid rolename.'
       '  Cannot start or end with a "/": ' + rolename)
