@@ -23,14 +23,6 @@
  behavior.
 """
 
-# Help with Python 3 compatibility, where the print statement is a function, an
-# implicit relative import is invalid, and the '/' operator performs true
-# division.  Example:  print 'hello world' raises a 'SyntaxError' exception.
-from __future__ import print_function
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
-
 
 # Set a directory that should be used for all temporary files. If this
 # is None, then the system default will be used. The system default
